==> ejc-ztpcct-impl-3.0.0-20231009.110533-44-sources.jar: com/ejianc/ztpc/vo/CheckDrawInfoVO.java <==
package com.ejianc.ztpc.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 图纸会检-图纸信息
 * 
 * @author generator
 * 
 */
public class CheckDrawInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 编码
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private Long pid; // 父ID
    private String drawCode; // 图纸编号
    private String drawName; // 图纸名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date drawArriveDate; // 到图日期
    private String remarks; // 备注
    

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public String getDrawCode() {
        return drawCode;
    }

    public void setDrawCode(String drawCode) {
        this.drawCode = drawCode;
    }
    public String getDrawName() {
        return drawName;
    }

    public void setDrawName(String drawName) {
        this.drawName = drawName;
    }
    public Date getDrawArriveDate() {
        return drawArriveDate;
    }

    public void setDrawArriveDate(Date drawArriveDate) {
        this.drawArriveDate = drawArriveDate;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    
}

==> ejc-ztpcct-impl-3.0.0-20231213.081627-65-sources.jar: com/ejianc/ztpc/vo/CheckDrawInfoVO.java <==
package com.ejianc.ztpc.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 图纸会检-图纸信息
 * 
 * @author generator
 * 
 */
public class CheckDrawInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 编码
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private Long pid; // 父ID
    private String drawCode; // 图纸编号
    private String drawName; // 图纸名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date drawArriveDate; // 到图日期
    private String remarks; // 备注
    private Long drawId; // 图纸ID
    

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public String getDrawCode() {
        return drawCode;
    }

    public void setDrawCode(String drawCode) {
        this.drawCode = drawCode;
    }
    public String getDrawName() {
        return drawName;
    }

    public void setDrawName(String drawName) {
        this.drawName = drawName;
    }
    public Date getDrawArriveDate() {
        return drawArriveDate;
    }

    public void setDrawArriveDate(Date drawArriveDate) {
        this.drawArriveDate = drawArriveDate;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

    public Long getDrawId() {
        return drawId;
    }

    public void setDrawId(Long drawId) {
        this.drawId = drawId;
    }
}
